import { PublicKey } from '@metaplex-foundation/umi';
/**
 * Creates a Merkle Root from the provided data.
 *
 * This root provides a short identifier for the
 * provided data that is unique and deterministic.
 * This means, we can use this root to verify that
 * a given data is part of the original data set.
 */
export declare const getMerkleRoot: (leaves: PublicKey[], maxDepth: number) => PublicKey;
/**
 * Creates a Merkle Proof for a given data item.
 *
 * This proof can be used to verify that the given
 * data item is part of the original data set.
 */
export declare const getMerkleProof: (leaves: PublicKey[], maxDepth: number, leaf: PublicKey, index?: number | undefined) => PublicKey[];
/**
 * Creates a Merkle Proof for a data item at a given index.
 *
 * This proof can be used to verify that the data item at
 * the given index is part of the original data set.
 */
export declare const getMerkleProofAtIndex: (leaves: PublicKey[], maxDepth: number, index: number) => PublicKey[];
